@@ -21,11 +21,11 @@
 def bcd2int(b):
     return (b & 0x0f) + ((b >> 4) * 10)
 
+def bin2int(s: str):
+    return int('0b' + s, 2)
+
 def bitpack(bits):
-    res = 0
-    for i, b in enumerate(bits):
-        res |= b << i
-    return res
+    return sum([b << i for i, b in enumerate(bits)])
 
 def bitunpack(num, minbits=0):
     res = []
