@@ -18,21 +18,18 @@
 ##
 
 '''
-EDID 1.3 structure decoder.
+Extended Display Identification Data (EDID) 1.3 structure decoder.
 
 The three-character vendor ID as specified in the EDID standard refers to
 a Plug and Play ID (PNPID). The list of PNPID assignments is done by Microsoft.
-More information is available on this page:
-
- http://msdn.microsoft.com/en-us/windows/hardware/gg463195
 
 The 'pnpids.txt' file included with this protocol decoder is derived from
 the list of assignments downloadable from that page. It was retrieved in
 January 2012.
 
-More information on EDID is available here:
-
- https://en.wikipedia.org/wiki/Extended_display_identification_data
+Details:
+https://en.wikipedia.org/wiki/Extended_display_identification_data
+http://msdn.microsoft.com/en-us/windows/hardware/gg463195
 '''
 
 from .pd import Decoder
